lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:   Mon, 22 Jun 2020 17:30:13 -0700
From:   paulmck@...nel.org
To:     rcu@...r.kernel.org
Cc:     linux-kernel@...r.kernel.org, kernel-team@...com, mingo@...nel.org,
        jiangshanlai@...il.com, dipankar@...ibm.com,
        akpm@...ux-foundation.org, mathieu.desnoyers@...icios.com,
        josh@...htriplett.org, tglx@...utronix.de, peterz@...radead.org,
        rostedt@...dmis.org, dhowells@...hat.com, edumazet@...gle.com,
        fweisbec@...il.com, oleg@...hat.com, joel@...lfernandes.org,
        "Paul E. McKenney" <paulmck@...nel.org>
Subject: [PATCH tip/core/rcu 30/30] refscale: Change --torture type from refperf to refscale

From: "Paul E. McKenney" <paulmck@...nel.org>

This commit renames the rcutorture config/refperf to config/refscale to
further avoid conflation with the Linux kernel's perf feature.

Reported-by: Ingo Molnar <mingo@...nel.org>
Signed-off-by: Paul E. McKenney <paulmck@...nel.org>
---
 .../bin/{kvm-recheck-refperf.sh => kvm-recheck-refscale.sh}       | 8 ++++----
 tools/testing/selftests/rcutorture/bin/kvm.sh                     | 8 ++++----
 tools/testing/selftests/rcutorture/bin/parse-console.sh           | 4 ++--
 .../selftests/rcutorture/configs/{refperf => refscale}/CFLIST     | 0
 .../selftests/rcutorture/configs/{refperf => refscale}/CFcommon   | 0
 .../selftests/rcutorture/configs/{refperf => refscale}/NOPREEMPT  | 0
 .../selftests/rcutorture/configs/{refperf => refscale}/PREEMPT    | 0
 .../rcutorture/configs/{refperf => refscale}/ver_functions.sh     | 0
 8 files changed, 10 insertions(+), 10 deletions(-)
 rename tools/testing/selftests/rcutorture/bin/{kvm-recheck-refperf.sh => kvm-recheck-refscale.sh} (87%)
 rename tools/testing/selftests/rcutorture/configs/{refperf => refscale}/CFLIST (100%)
 rename tools/testing/selftests/rcutorture/configs/{refperf => refscale}/CFcommon (100%)
 rename tools/testing/selftests/rcutorture/configs/{refperf => refscale}/NOPREEMPT (100%)
 rename tools/testing/selftests/rcutorture/configs/{refperf => refscale}/PREEMPT (100%)
 rename tools/testing/selftests/rcutorture/configs/{refperf => refscale}/ver_functions.sh (100%)

diff --git a/tools/testing/selftests/rcutorture/bin/kvm-recheck-refperf.sh b/tools/testing/selftests/rcutorture/bin/kvm-recheck-refscale.sh
similarity index 87%
rename from tools/testing/selftests/rcutorture/bin/kvm-recheck-refperf.sh
rename to tools/testing/selftests/rcutorture/bin/kvm-recheck-refscale.sh
index 0e29cfd..35a463d 100755
--- a/tools/testing/selftests/rcutorture/bin/kvm-recheck-refperf.sh
+++ b/tools/testing/selftests/rcutorture/bin/kvm-recheck-refscale.sh
@@ -1,9 +1,9 @@
 #!/bin/bash
 # SPDX-License-Identifier: GPL-2.0+
 #
 # Analyze a given results directory for refperf performance measurements.
 #
-# Usage: kvm-recheck-refperf.sh resdir
+# Usage: kvm-recheck-refscale.sh resdir
 #
 # Copyright (C) IBM Corporation, 2016
 #
@@ -51,7 +51,7 @@ END {
 	print configfile " results:";
 	newNR = asort(readertimes);
 	if (newNR <= 0) {
-		print "No refperf records found???"
+		print "No refscale records found???"
 		exit;
 	}
 	medianidx = int(newNR / 2);
@@ -67,5 +67,5 @@ END {
 	print "Minimum reader duration: " readertimes[1];
 	print "Median reader duration: " medianvalue;
 	print "Maximum reader duration: " readertimes[newNR];
-	print "Computed from refperf printk output.";
+	print "Computed from refscale printk output.";
 }'
@@ -1,9 +1,9 @@
 # SPDX-License-Identifier: GPL-2.0+
 #
-# Analyze a given results directory for refperf performance measurements.
+# Analyze a given results directory for refscale performance measurements.
 #
diff --git a/tools/testing/selftests/rcutorture/bin/kvm.sh b/tools/testing/selftests/rcutorture/bin/kvm.sh
index 48b6a72..ce05db3 100755
--- a/tools/testing/selftests/rcutorture/bin/kvm.sh
+++ b/tools/testing/selftests/rcutorture/bin/kvm.sh
@@ -180,14 +180,14 @@ do
 		shift
 		;;
 	--torture)
-		checkarg --torture "(suite name)" "$#" "$2" '^\(lock\|rcu\|rcuperf\|refperf\)$' '^--'
+		checkarg --torture "(suite name)" "$#" "$2" '^\(lock\|rcu\|rcuperf\|refscale\)$' '^--'
 		TORTURE_SUITE=$2
 		shift
-		if test "$TORTURE_SUITE" = rcuperf || test "$TORTURE_SUITE" = refperf
+		if test "$TORTURE_SUITE" = rcuperf || test "$TORTURE_SUITE" = refscale
 		then
 			# If you really want jitter for refperf or
 			# rcuperf, specify it after specifying the rcuperf
 			# or the refperf.  (But why jitter in these cases?)
 			jitter=0
 		fi
 		;;
@@ -180,14 +180,14 @@ do
 		then
-			# If you really want jitter for refperf or
+			# If you really want jitter for refscale or
 			# rcuperf, specify it after specifying the rcuperf
@@ -180,14 +180,14 @@ do
 			# rcuperf, specify it after specifying the rcuperf
-			# or the refperf.  (But why jitter in these cases?)
+			# or the refscale.  (But why jitter in these cases?)
 			jitter=0
 		fi
diff --git a/tools/testing/selftests/rcutorture/bin/parse-console.sh b/tools/testing/selftests/rcutorture/bin/parse-console.sh
index 85af11d..8cb908f 100755
--- a/tools/testing/selftests/rcutorture/bin/parse-console.sh
+++ b/tools/testing/selftests/rcutorture/bin/parse-console.sh
@@ -33,8 +33,8 @@ then
 fi
 cat /dev/null > $file.diags
 
-# Check for proper termination, except for rcuperf and refperf.
-if test "$TORTURE_SUITE" != rcuperf && test "$TORTURE_SUITE" != refperf
+# Check for proper termination, except for rcuperf and refscale.
+if test "$TORTURE_SUITE" != rcuperf && test "$TORTURE_SUITE" != refscale
 then
 	# check for abject failure
 
diff --git a/tools/testing/selftests/rcutorture/configs/refperf/CFLIST b/tools/testing/selftests/rcutorture/configs/refscale/CFLIST
similarity index 100%
rename from tools/testing/selftests/rcutorture/configs/refperf/CFLIST
rename to tools/testing/selftests/rcutorture/configs/refscale/CFLIST
diff --git a/tools/testing/selftests/rcutorture/configs/refperf/CFcommon b/tools/testing/selftests/rcutorture/configs/refscale/CFcommon
similarity index 100%
rename from tools/testing/selftests/rcutorture/configs/refperf/CFcommon
rename to tools/testing/selftests/rcutorture/configs/refscale/CFcommon
diff --git a/tools/testing/selftests/rcutorture/configs/refperf/NOPREEMPT b/tools/testing/selftests/rcutorture/configs/refscale/NOPREEMPT
similarity index 100%
rename from tools/testing/selftests/rcutorture/configs/refperf/NOPREEMPT
rename to tools/testing/selftests/rcutorture/configs/refscale/NOPREEMPT
diff --git a/tools/testing/selftests/rcutorture/configs/refperf/PREEMPT b/tools/testing/selftests/rcutorture/configs/refscale/PREEMPT
similarity index 100%
rename from tools/testing/selftests/rcutorture/configs/refperf/PREEMPT
rename to tools/testing/selftests/rcutorture/configs/refscale/PREEMPT
diff --git a/tools/testing/selftests/rcutorture/configs/refperf/ver_functions.sh b/tools/testing/selftests/rcutorture/configs/refscale/ver_functions.sh
similarity index 100%
rename from tools/testing/selftests/rcutorture/configs/refperf/ver_functions.sh
rename to tools/testing/selftests/rcutorture/configs/refscale/ver_functions.sh
-- 
2.9.5

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ